def time_def_(func):
    """
    example:
    @time_def_
    def time_sleep(r, r2):
        time.sleep(1)
        return r, r2

    time_sleep(1, r2=4)
    # func: time_sleep, res=(1, 4), time: 1.0127627849578857 s
    """
    def wrapper(*args, **kwargs):
        import time
        start = time.time()
        res = func(*args, **kwargs)
        end = time.time()
        print(f"func: {func.__name__}, {res=}, time: {end - start} s")
        return res
    return wrapper


#==========================================
# Title:  time_def_
# Author: MaxF39
# Date:   23.06.2022
#==========================================

from setuptools import setup

setup(name='time_def',
      version='0.3',
      description='Print how long the function has been running',
      packages=['time_def'],
      author="Maxim Fedotov",
      author_email='maxf39@mail.ru',
      zip_safe=False)